@@ -92,16 +92,15 @@ class Review(Base):
         return len(self.violations)
 
     @classmethod
-    def get_by_violation_key_name(cls, db, key_name, current_page=1, page_size=10):
+    def get_by_violation_key_name(cls, db, key_id, current_page=1, page_size=10):
 
         from holmes.models.violation import Violation  # to avoid circular dependency
-        from holmes.models.keys import Key  # to avoid circular dependency
         from holmes.models.page import Page  # to avoid circular dependency
 
         lower_bound = (current_page - 1) * page_size
         upper_bound = lower_bound + page_size
 
-        query = db \
+        return db \
             .query(
                 Review.uuid.label('review_uuid'),
                 Page.url,
@@ -111,7 +110,5 @@ class Review(Base):
             .filter(Page.id == Review.page_id) \
             .filter(Violation.review_id == Review.id) \
             .filter(Review.is_active == True) \
-            .filter(Key.id == Violation.key_id) \
-            .filter(Key.name == key_name)
-
-        return query.count(), query[lower_bound:upper_bound]
+            .filter(Violation.key_id == key_id) \
+            .order_by(Review.completed_date.desc())[lower_bound:upper_bound]
